@@ -6,8 +6,8 @@ class Venue(models.Model):
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
 
-    def __init__(self):
-        self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
+    def __init__(self, *args, **kwargs):
+        self.venue_root = os.path.abspath(os.path.join(venue_path, venue_name))
     """
         if not os.path.exists(self.venue_root):
             print 'venue does not exist at %s' % self.venue_root
