@@ -112,6 +112,10 @@ class Venue():
             except:
                 pass
 
+    def get_uwsgi_port(self):
+        self.uwsgi_ip, self.uwsgi_port = uwsgi_portsniffer.get_uwsgi_port(self.UWSGI_INI)
+        return
+
     def reload(self):
         """Reload the Venue, by touching its ini file"""
         try:
@@ -120,7 +124,7 @@ class Venue():
         except IOError:
             print 'Could not update, permission denied.'
             return
-        self.uwsgi_ip, self.uwsgi_port = uwsgi_portsniffer.get_uwsgi_port(self.UWSGI_INI)
+        self.get_uwsgi_port()
         return
 
 
